Aglyph 3.0.0 testing summary — Aglyph 3.0.0 documentation

# Aglyph 3.0.0 testing summary

Warning

Changed in version 3.0.0.

The Python 3.3 lifespan has ended; the Aglyph test suite is no longer executed under this version.

Note

Prior to each Aglyph release being committed, tagged, and packaged, its test suite is executed on several Python implementations, versions, and platforms.

When a Python version reaches end-of-life, the Aglyph test suite is no longer “officially” executed against that version. This does not necessarily imply that Aglyph unit tests fail under that Python version; it simply means that I no longer publish or withhold a release based on the test suite results from that particular Python version.

## CPython

Version | Platform
--- | ---
3.7.0b2 | [GCC 7.3.1 20180130 (Red Hat 7.3.1-2)] on Linux-4.15.8-300.fc27.x86_64-x86_64-with-fedora-27-Twenty_Seven
| [Clang 6.0 (clang-600.0.57)] on Darwin-17.4.0-x86_64-i386-64bit (Mac OS 10.13.3)
| [MSC v.1912 64 bit (AMD64)] on Windows-10-10.0.16299-SP0
3.6.4 | [GCC 7.3.1 20180130 (Red Hat 7.3.1-2)] on Linux-4.15.8-300.fc27.x86_64-x86_64-with-fedora-27-Twenty_Seven
| [GCC 4.2.1 Compatible Apple LLVM 9.0.0 (clang-900.0.38)] on Darwin-17.4.0-x86_64-i386-64bit (Mac OS X 10.13.3)
| [MSC v.1900 64 bit (AMD64)] on Windows-10-10.0.16299-SP0
3.5.5 | [GCC 4.2.1 Compatible Apple LLVM 9.0.0 (clang-900.0.39.2)] on Darwin-17.4.0-x86_64-i386-64bit (Mac OS X 10.13.3)
| [MSC v.1900 64 bit (AMD64)] on Windows-10-10.0.16299-SP0
3.5.4 | [GCC 7.2.1 20170915 (Red Hat 7.2.1-2)] on Linux-4.15.8-300.fc27.x86_64-x86_64-with-fedora-27-Twenty_Seven
3.4.8 | [GCC 4.2.1 Compatible Apple LLVM 9.0.0 (clang-900.0.39.2)] on Darwin-17.4.0-x86_64-i386-64bit (Mac OS X 10.13.3)
3.4.7 | [GCC 7.2.1 20170915 (Red Hat 7.2.1-2)] on Linux-4.15.8-300.fc27.x86_64-x86_64-with-fedora-27-Twenty_Seven
3.4.4 | [MSC v.1600 64 bit (AMD64)] on Windows-10-10.0.16299
2.7.14 | [GCC 7.3.1 20180130 (Red Hat 7.3.1-2)] on Linux-4.15.8-300.fc27.x86_64-x86_64-with-fedora-27-Twenty_Seven
| [MSC v.1500 64 bit (AMD64)] on Windows-10-10.0.16299
| [GCC 4.2.1 Compatible Apple LLVM 9.0.0 (clang-900.0.37)] on Darwin-17.4.0-x86_64-i386-64bit (Mac OS X 10.13.3)

## PyPy

Version | Platform
--- | ---
3.5.3 | [PyPy 5.10.1 with GCC 7.2.0] on Linux-4.15.8-300.fc27.x86_64-x86_64-with-fedora-27-Twenty_Seven
| [PyPy 5.10.1 with MSC v.1500 32 bit] on Windows-8-6.2.9200-SP0
2.7.13 | [PyPy 5.10.0 with GCC 7.2.0] on Linux-4.15.8-300.fc27.x86_64-x86_64-with-fedora-27-Twenty_Seven
| [PyPy 5.10.0 with GCC 4.2.1 Compatible Apple LLVM 9.0.0 (clang-900.0.39.2)] on Darwin-17.4.0-x86_64-i386-64bit (Mac OS X 10.13.3)
| [PyPy 5.9.0 with MSC v.1500 32 bit] on Windows-10-10.0.16299

## Stackless Python

Version | Platform
--- | ---
3.6.4 | Stackless 3.1b3 [GCC 6.4.1 20170727 (Red Hat 6.4.1-1)] on Linux-4.15.8-300.fc27.x86_64-x86_64-with-fedora-27-Twenty_Seven
| Stackless 3.1b3 [GCC 4.2.1 Compatible Apple LLVM 9.0.0 (clang-900.0.39.2)] on Darwin-17.4.0-x86_64-i386-64bit (Mac OS X 10.13.3)
| Stackless 3.1b3 [MSC v.1900 64 bit (AMD64)] on Windows-10-10.0.16299-SP0
3.5.4 | Stackless 3.1b3 [MSC v.1900 64 bit (AMD64)] on Windows-10-10.0.16299-SP0
2.7.14 | Stackless 3.1b3 [GCC 6.4.1 20170727 (Red Hat 6.4.1-1)] on Linux-4.15.8-300.fc27.x86_64-x86_64-with-fedora-27-Twenty_Seven
| Stackless 3.1b3 [GCC 4.2.1 Compatible Apple LLVM 9.0.0 (clang-900.0.39.2)] on Darwin-17.4.0-x86_64-i386-64bit (Mac OS X 10.13.3)
| Stackless 3.1b3 [MSC v.1500 64 bit (AMD64)] on Windows-10-10.0.16299

## Jython

Version | Platform
--- | ---
2.7.1 | [OpenJDK 64-Bit Server VM (Oracle Corporation)] on Java-9.0.4-OpenJDK_64-Bit_Server_VM,_9.0.4+11,_Oracle_Corporation-on-Linux-4.15.8-300.fc27.x86_64-amd64
| [Java HotSpot(TM) 64-Bit Server VM (Oracle Corporation)] on java9.0.4 ( ==darwin for targets ) (Mac OS X 10.13.3)
| [Java HotSpot(TM) 64-Bit Server VM (Oracle Corporation)] on java1.8.0_162 ( ==darwin for targets ) (Mac OS X 10.13.3)
| [Java HotSpot(TM) 64-Bit Server VM (Oracle Corporation)] on Java-9.0.4-Java_HotSpot-TM-_64-Bit_Server_VM,_9.0.4+11,_Oracle_Corporation-on-Windows_10-10.0-amd64
2.7.0 | [OpenJDK 64-Bit Server VM (Oracle Corporation)] on Java-1.8.0_161-OpenJDK_64-Bit_Server_VM,_25.161-b14,_Oracle_Corporation-on-Linux-4.15.8-300.fc27.x86_64-amd64

## IronPython

Version | Platform
--- | ---
2.7.7 | cli-10-AMD64-Intel64_Family_6_Model_94_Stepping_3,_GenuineIntel-64bit [.NET 4.0.30319.42000 (64-bit)] on Windows 10 Home v1709 build 16299.251
| cli-10-AMD64-Intel64_Family_6_Model_94_Stepping_3,_GenuineIntel-32bit [.NET 4.0.30319.42000 (32-bit)] on Windows 10 Home v1709 build 16299.251

## Previous releases of Aglyph

- Aglyph 2.1.1 testing summary
- Aglyph 2.1.0 testing summary
- Aglyph 2.0.0 testing summary
- Aglyph 1.1.1 testing summary
- Aglyph 1.1.0 testing summary